@@ -33,6 +33,8 @@ class VisVariables():
         ylabel : Optional[str] = None,
         xlabelsize : Optional[float] = None,
         ylabelsize : Optional[float] = None,
+        xticksize : Optional[float] = None,
+        yticksize : Optional[float] = None,
         xlim : Optional[List[float]] = None,
         ylim : Optional[List[float]] = None,
         title : Optional[str] = None,
